@@ -7,9 +7,7 @@
 #  Authors: Revva Konstantin <k.revva@abm-jsc.ru>
 
 
-from detector_connector import DetectorKafkaConnector
-
-from .obstruction_analyze_result import ObstructionAnalyzeResult
+from detector_connector import DetectorKafkaConnector, DetectorAnalyzeResult
 
 
 class ObstructionDetectorKafkaConnector(DetectorKafkaConnector):
@@ -17,4 +15,4 @@ class ObstructionDetectorKafkaConnector(DetectorKafkaConnector):
     Config = DetectorKafkaConnector.Config
 
     def __init__(self, config: Config, context: Context):
-        super().__init__(config=config, context=context, detector_analyze_result_type=ObstructionAnalyzeResult)
+        super().__init__(config=config, context=context, detector_analyze_result_type=DetectorAnalyzeResult)
